==> haskell-src-meta-0.8.12-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-meta
version:              0.8.12
visibility:           public
id:                   haskell-src-meta-0.8.12-3aFnqQE0XF33tohreEbzmX
key:                  haskell-src-meta-0.8.12-3aFnqQE0XF33tohreEbzmX
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  b49586eb7481fd739d7b943030aafe5f
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-src-meta-0.8.12
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-src-meta-0.8.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.12-3aFnqQE0XF33tohreEbzmX
depends:
    base-4.16.4.0 haskell-src-exts-1.23.1-E0P4HoETA4eJMgK1YQrOqi
    pretty-1.1.3.6 syb-0.7.2.4-3l4i7x4UWHaFMYIEmP3T6l
    template-haskell-2.18.0.0 th-orphans-0.13.14-IFdr808Ei4NTG64FhXomg

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.12-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-meta
version:              0.8.12
visibility:           public
id:                   haskell-src-meta-0.8.12-Fe5kGltKJxeIZkKj5WAOn4
key:                  haskell-src-meta-0.8.12-Fe5kGltKJxeIZkKj5WAOn4
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  4509b67bc81535242c7c0ccc3cde6ed5
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-src-meta-0.8.12
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-src-meta-0.8.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.12-Fe5kGltKJxeIZkKj5WAOn4
depends:
    base-4.16.4.0 haskell-src-exts-1.23.1-EQsaf5CMOxi6fZopto4Klc
    pretty-1.1.3.6 syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s
    template-haskell-2.18.0.0 th-orphans-0.13.14-9IVv0eQKqVy5rA0nZ47ezc

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
